@@ -4,6 +4,7 @@ use cursive_core::{
     view::Nameable,
     event::{Event, Key},
     views::{EditView, Dialog, OnEventView, NamedView},
+    utils::markup::StyledString,
     theme::{
         PaletteColor,
         Color,
@@ -19,8 +20,7 @@ use std::fmt::Display;
 /// 
 /// # Example
 /// ```
-/// use cursive_extras::*;
-/// 
+/// # use cursive_extras::*;
 /// let mut root = cursive::default();
 /// root.set_theme(better_theme());
 /// ```
@@ -31,7 +31,7 @@ pub fn better_theme() -> Theme {
     theme_def.palette[PaletteColor::Primary] = Color::Light(BaseColor::White);
     theme_def.palette[PaletteColor::View] = Color::TerminalDefault;
     theme_def.palette[PaletteColor::Highlight] = Color::Light(BaseColor::Blue);
-    theme_def.palette[PaletteColor::HighlightText] = Color::Dark(BaseColor::Black);
+    theme_def.palette[PaletteColor::HighlightText] = Color::Dark(BaseColor::White);
     theme_def.palette[PaletteColor::Secondary] = Color::Dark(BaseColor::Blue);
     theme_def.palette[PaletteColor::TitlePrimary] = Color::Light(BaseColor::Blue);
     theme_def.borders = BorderStyle::Outset;
@@ -43,8 +43,7 @@ pub fn better_theme() -> Theme {
 /// 
 /// # Example
 /// ```
-/// use cursive_extras::*;
-/// 
+/// # use cursive_extras::*;
 /// let mut root = cursive::default();
 /// # root.set_theme(better_theme());
 /// root.add_layer(confirm_dialog("Are you sure?", "Are you sure?", |view| view.quit()));
@@ -64,13 +63,22 @@ pub fn confirm_dialog<C, T, U>(title: T, text: U, cb: C) -> OnEventView<Dialog>
         .on_event(Event::Key(Key::Esc), |v| { v.pop_layer(); })
 }
 
+/// Same as `confirm_dialog()`, but accepts `StyledString`s instead for the text
+pub fn confirm_dialog_styled<T:Display, C: Fn(&mut Cursive) + 'static>(title: T, text: StyledString, cb: C) -> OnEventView<Dialog> {
+    Dialog::text(text)
+        .dismiss_button("No")
+        .button("Yes", cb)
+        .title(title.to_string())
+        .wrap_with(OnEventView::new)
+        .on_event(Event::Key(Key::Esc), |v| { v.pop_layer(); })
+}
+
 /// Convenience function that shows a user a dialog box
 /// with a message that includes a back button
 /// 
 /// # Example
 /// ```
-/// use cursive_extras::*;
-/// 
+/// # use cursive_extras::*;
 /// let mut root = cursive::default();
 /// # root.set_theme(better_theme());
 /// root.add_layer(info_dialog("Info", "This is important!"));
@@ -84,14 +92,22 @@ pub fn info_dialog<T: Display, U: Display>(title: T, text: U) -> OnEventView<Dia
         .on_event(Event::Key(Key::Esc), |v| { v.pop_layer(); })
 }
 
+/// Sames as `info_dialog()`, but accepts `StyledString`s instead for the text
+pub fn info_dialog_styled<T: Display>(title: T, text: StyledString) -> OnEventView<Dialog> {
+    Dialog::text(text)
+        .dismiss_button("Back")
+        .title(title.to_string())
+        .wrap_with(OnEventView::new)
+        .on_event(Event::Key(Key::Esc), |v| { v.pop_layer(); })
+}
+
 /// Convenience function that creates a named `EditView` that has a better
 /// looking style and can optionally act as a password entry box
 /// 
 /// # Example
 /// ```
-/// use cursive::views::Dialog;
-/// use cursive_extras::*;
-/// 
+/// # use cursive::views::Dialog;
+/// # use cursive_extras::*;
 /// let mut root = cursive::default();
 /// # root.set_theme(better_theme());
 /// root.add_fullscreen_layer(
